summaryrefslogtreecommitdiffhomepage
path: root/packages/ui/src/custom-elements.d.ts
diff options
context:
space:
mode:
authorAdam <[email protected]>2025-12-15 10:56:03 -0600
committerAdam <[email protected]>2025-12-15 10:56:07 -0600
commitb7a9cbfc684048746e37f609ec6f42449faabca4 (patch)
tree94f0400808164e21ca33b0178d4db25db4c608f8 /packages/ui/src/custom-elements.d.ts
parent46a35dfc1b99c77da66a055510640c797f32a0ce (diff)
downloadopencode-b7a9cbfc684048746e37f609ec6f42449faabca4.tar.gz
opencode-b7a9cbfc684048746e37f609ec6f42449faabca4.zip
fix: share page
Diffstat (limited to 'packages/ui/src/custom-elements.d.ts')
-rw-r--r--packages/ui/src/custom-elements.d.ts8
1 files changed, 4 insertions, 4 deletions
diff --git a/packages/ui/src/custom-elements.d.ts b/packages/ui/src/custom-elements.d.ts
index 6ad3ea34e..b756e51da 100644
--- a/packages/ui/src/custom-elements.d.ts
+++ b/packages/ui/src/custom-elements.d.ts
@@ -1,12 +1,12 @@
/**
* TypeScript declaration for the <file-diff> custom element.
* This tells TypeScript that <file-diff> is a valid JSX element in SolidJS.
* Required for using the precision-diffs web component in .tsx files.
*/
declare module "solid-js" {
namespace JSX {
interface IntrinsicElements {
- "file-diff": HTMLAttributes<HTMLElement>
+ "diffs-container": HTMLAttributes<HTMLElement>
}
}
}
@@ -1,12 +1,12 @@
/**
- * TypeScript declaration for the <file-diff> custom element.
- * This tells TypeScript that <file-diff> is a valid JSX element in SolidJS.
- * Required for using the precision-diffs web component in .tsx files.
+ * TypeScript declaration for the <diffs-container> custom element.
+ * This tells TypeScript that <diffs-container> is a valid JSX element in SolidJS.
+ * Required for using the @pierre/diffs web component in .tsx files.
*/
declare module "solid-js" {